Fix sample 11_texture_driver for hip-clang (#1370)

Этот коммит содержится в:
Yaxun (Sam) Liu
2019-08-28 21:03:20 -04:00
коммит произвёл Maneesh Gupta
родитель 19a9b15306
Коммит 793b18c0b1
+6 -1
Просмотреть файл
@@ -21,7 +21,12 @@ THE SOFTWARE.
*/
#include "hip/hip_runtime.h"
extern texture<float, 2, hipReadModeElementType> tex;
#if __HIP__
__hip_pinned_shadow__
#else
extern
#endif
texture<float, 2, hipReadModeElementType> tex;
extern "C" __global__ void tex2dKernel(float* outputData, int width, int height) {
int x = hipBlockIdx_x * hipBlockDim_x + hipThreadIdx_x;